@@ -1,7 +1,8 @@
 package Strehler::Dancer2::Plugin::Admin;
-$Strehler::Dancer2::Plugin::Admin::VERSION = '1.5.1';
+$Strehler::Dancer2::Plugin::Admin::VERSION = '1.5.5';
 use strict;
 use Dancer2::Plugin;
+use Strehler;
 use Strehler::Helpers;
 
 on_plugin_import {
@@ -59,6 +60,8 @@ on_plugin_import {
             {
                 $tokens->{'dashboard_active'} = 0;
             }
+            $tokens->{'warnings'} = 1 if(! Strehler::Helpers::check_statics());
+            $tokens->{'strehler_version'} = $Strehler::VERSION;
         }));
     };
     
