@@ -1,5 +1,5 @@
 package Strehler::Element::Article;
-$Strehler::Element::Article::VERSION = '1.5.1';
+$Strehler::Element::Article::VERSION = '1.5.5';
 use strict;
 use Cwd 'abs_path';
 use Moo;
@@ -172,6 +172,11 @@ sub entity_js
     my $self = shift;
     return $self->_property('entity_js', '/strehler/js/article.js');
 }
+sub install
+{
+    return "Standard entity. No installation is needed.";
+}
+
 
 =encoding utf8
 
