@@ -1,5 +1,5 @@
 package Strehler::Element::Image;
-$Strehler::Element::Image::VERSION = '1.5.1';
+$Strehler::Element::Image::VERSION = '1.5.5';
 use strict;
 use Cwd 'abs_path';
 use Moo;
@@ -103,7 +103,7 @@ sub save_form
     
     if($img)
     {
-        $public = app->config->{public} || path( app->config_location, 'public' );
+        $public = Strehler::Helpers::public_directory();
         $ref = '/upload/' . $img->filename;
         $path = $public . $ref;
         $img->copy_to($path);
@@ -175,6 +175,11 @@ sub custom_list_template
     return $views_path . "/admin/blocks/image_list_block.tt";
 }
 
+sub install
+{
+    return "Standard entity. No installation is needed.";
+}
+
 =encoding utf8
 
 =head1 NAME
