@@ -1,5 +1,5 @@
 package Strehler::Element::Log;
-$Strehler::Element::Log::VERSION = '1.5.1';
+$Strehler::Element::Log::VERSION = '1.5.5';
 use strict;
 use Moo;
 use Dancer2 0.154000;
@@ -105,6 +105,12 @@ sub custom_list_template
     return $views_path . "/admin/blocks/log_list_block.tt";
 }
 
+sub install
+{
+    return "Standard entity. No installation is needed.";
+}
+
+
 
 =encoding utf8
 
