@@ -1,5 +1,5 @@
 package Strehler::Element::User;
-$Strehler::Element::User::VERSION = '1.5.1';
+$Strehler::Element::User::VERSION = '1.5.5';
 use strict;
 use Moo;
 use Dancer2 0.154000;
@@ -156,6 +156,12 @@ sub get_from_username
     }
 }
 
+sub install
+{
+    return "Standard entity. No installation is needed.";
+}
+
+
 =encoding utf8
 
 =head1 NAME
