@@ -1,7 +1,8 @@
 package Strehler::Helpers;
-$Strehler::Helpers::VERSION = '1.5.1';
+$Strehler::Helpers::VERSION = '1.5.5';
 use strict;
 use Dancer2 0.154000;
+use Strehler;
 use Unicode::Normalize;
 use Text::Unidecode;
 
@@ -123,6 +124,21 @@ sub class_from_plural
     return undef;
 }
 
+sub public_directory
+{
+    my $public_directory = app->config->{public} || path( app->config_location, 'public' );
+    return $public_directory;
+}
+
+sub check_statics
+{
+    my $public_directory = public_directory();
+    open(my $version_file, "< $public_directory/strehler/VERSION") || return 0;
+    my $data = <$version_file>;
+    chomp $data;
+    return $data eq $Strehler::STATICS_VERSION ? 1: 0;
+}
+
 =encoding utf8
 
 =head1 NAME
